summaryrefslogtreecommitdiff
path: root/bootloader/imx233.c
diff options
context:
space:
mode:
Diffstat (limited to 'bootloader/imx233.c')
-rw-r--r--bootloader/imx233.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/bootloader/imx233.c b/bootloader/imx233.c
index 65799de..efe19bf 100644
--- a/bootloader/imx233.c
+++ b/bootloader/imx233.c
@@ -217,9 +217,9 @@ void main(uint32_t arg, uint32_t addr)
system_prepare_fw_start();
/* if target defines lcd_enable() in bootloader, take this as a hint that
* we should use it to properly stop the lcd before moving one, the
* _backlight_off() routine is supposed to disable the lcd at the same time */
#ifdef HAVE_LCD_ENABLE
- _backlight_off();
+ backlight_hw_off();
#endif
disable_interrupt(IRQ_FIQ_STATUS);
commit_discard_idcache();
@@ -217,9 +217,9 @@ void main(uint32_t arg, uint32_t addr)
/* if target defines lcd_enable() in bootloader, take this as a hint that
* we should use it to properly stop the lcd before moving one, the
- * _backlight_off() routine is supposed to disable the lcd at the same time */
+ * backlight_hw_off() routine is supposed to disable the lcd at the same time */
#ifdef HAVE_LCD_ENABLE